@@ -179,12 +179,13 @@ plot_coveff.coveffsim <- function(x, ...) {
     coveffsim_for_plot |>
     ggplot2::ggplot(ggplot2::aes(x = .odds_ratio, y = var_value_index_num)) +
     ggplot2::geom_point(size = 4) +
-    ggplot2::geom_errorbarh(
+    ggplot2::geom_errorbar(
       ggplot2::aes(xmin = .lower, xmax = .upper),
-      height = 0.3
+      orientation = "y",
+      width = 0.3
     ) +
     ggplot2::geom_vline(xintercept = 1, linetype = "dashed") +
-    xgxr::xgx_scale_x_log10() +
+    xgxr::xgx_scale_x_log10(guide = ggplot2::guide_axis(minor.ticks = TRUE)) +
     ggforce::facet_col(~var_label, scales = "free_y", space = "free") +
     ggplot2::labs(x = "Odds ratio") +
     ggplot2::scale_y_continuous(
