@@ -72,7 +72,7 @@ eval_ermod <- function(
   }
 
   if (eval_type == "kfold") {
-    cv_results <- run_kfold_cv(
+    cv_results <- kfold(
       ermod,
       newdata = data_to_use, k = k, seed = seed_kfold
     )
@@ -131,8 +131,9 @@ eval_ermod <- function(
   return(metrics)
 }
 
-
 .if_run_ex_eval_mod <- function() {
   requireNamespace("rsample", quietly = TRUE) &&
-    requireNamespace("yardstick", quietly = TRUE)
+    requireNamespace("yardstick", quietly = TRUE) &&
+    requireNamespace("digest", quietly = TRUE) &&
+    rlang::is_installed("rstanemax", version = "0.1.9")
 }
